@@ -1,11 +1,12 @@
 #!/usr/bin/env sh
 
-if [[ "$TRAVIS_OS_NAME" == "windows" ]]; then
+if [ "$TRAVIS_OS_NAME" = "windows" ]; then
     export GRADLE_OPTS=-Dorg.gradle.daemon=false
-    export PATH=$PATH:"/c/Program Files/Java/jdk1.8.0_201/bin"
+    export PATH=$PATH:"/c/Program Files/Java/jdk1.8.0_231/bin"
+    export JAVA_HOME="/c/Program Files/Java/jdk1.8.0_231"
     ./gradlew.bat build shadowJar proguard
 else
     ./gradlew build shadowJar proguard
 fi
 
-exit $?
\ No newline at end of file
+exit $?
